@@ -43,19 +43,24 @@ namespace KScreen
 class ConfigOperation;
 }
 
+namespace Ui
+{
+class KScreenWidget;
+}
+
 class Widget : public QWidget
 {
     Q_OBJECT
 
   public:
     explicit Widget(QWidget *parent = nullptr);
-    virtual ~Widget();
+    ~Widget() override;
 
     void setConfig(const KScreen::ConfigPtr &config);
     KScreen::ConfigPtr currentConfig() const;
 
   protected:
-    bool eventFilter(QObject *object, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *object, QEvent *event) override;
 
   Q_SIGNALS:
     void changed();
@@ -64,6 +69,7 @@ class Widget : public QWidget
     void slotFocusedOutputChanged(QMLOutput *output);
 
     void slotOutputEnabledChanged();
+    void slotOutputConnectedChanged();
 
     void slotUnifyOutputs();
     void slotProfileChanged(int index);
@@ -75,32 +81,32 @@ class Widget : public QWidget
     void slotIdentifyOutputs(KScreen::ConfigOperation *op);
     void clearOutputIdentifiers();
 
+    void outputAdded(const KScreen::OutputPtr &output);
+    void outputRemoved(int outputId);
+    void primaryOutputSelected(int index);
+    void primaryOutputChanged(const KScreen::OutputPtr &output);
+
   private:
     void loadQml();
-    void initPrimaryCombo();
+    void resetPrimaryCombo();
+    void addOutputToPrimaryCombo(const KScreen::OutputPtr &output);
 
     KScreen::OutputPtr findOutput(const KScreen::ConfigPtr &config, const QVariantMap &info);
 
   private:
+    Ui::KScreenWidget *ui;
     QMLScreen *mScreen = nullptr;
-    KScreen::ConfigPtr mConfig;
-    KScreen::ConfigPtr mPrevConfig;
+    KScreen::ConfigPtr mConfig = nullptr;
+    KScreen::ConfigPtr mPrevConfig = nullptr;
 
-    QQuickWidget *mDeclarativeView = nullptr;
     ControlPanel *mControlPanel = nullptr;
 
     ProfilesModel *mProfilesModel = nullptr;
-    PrimaryOutputCombo *mPrimaryCombo = nullptr;
-    QLabel *mPrimaryLabel = nullptr;
     QComboBox *mProfilesCombo = nullptr;
-
-    QPushButton *mScaleAllOutputsButton = nullptr;
-    QPushButton *mUnifyButton = nullptr;
     QPushButton *mSaveProfileButton = nullptr;
 
     QList<QQuickView*> mOutputIdentifiers;
     QTimer *mOutputTimer = nullptr;
-
 };
 
 #endif // WIDGET_H
